"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getText = exports.removeRange = exports.remove = exports.replaceTextRange = exports.replaceText = exports.insertTextBeforeRange = exports.insertTextBefore = exports.insertTextAfterRange = exports.insertTextAfter = exports.insertTextAt = void 0;
/**
 * Creates a fix command that inserts text at the specified index in the source text.
 * @param {int} index The 0-based index at which to insert the new text.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 * @private
 */
function insertTextAt(index, text) {
    return {
        range: [index, index],
        text
    };
}
exports.insertTextAt = insertTextAt;
/**
 * Creates a fix command that inserts text after the given node or token.
 * The fix is not applied until applyFixes() is called.
 * @param {Node|Token} nodeOrToken The node or token to insert after.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 */
function insertTextAfter(nodeOrToken, text) {
    return insertTextAfterRange(nodeOrToken.range, text);
}
exports.insertTextAfter = insertTextAfter;
/**
 * Creates a fix command that inserts text after the specified range in the source text.
 * The fix is not applied until applyFixes() is called.
 * @param {int[]} range The range to replace, first item is start of range, second
 *      is end of range.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 */
function insertTextAfterRange(range, text) {
    return insertTextAt(range[1], text);
}
exports.insertTextAfterRange = insertTextAfterRange;
/**
 * Creates a fix command that inserts text before the given node or token.
 * The fix is not applied until applyFixes() is called.
 * @param {Node|Token} nodeOrToken The node or token to insert before.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 */
function insertTextBefore(nodeOrToken, text) {
    return insertTextBeforeRange(nodeOrToken.range, text);
}
exports.insertTextBefore = insertTextBefore;
/**
 * Creates a fix command that inserts text before the specified range in the source text.
 * The fix is not applied until applyFixes() is called.
 * @param {int[]} range The range to replace, first item is start of range, second
 *      is end of range.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 */
function insertTextBeforeRange(range, text) {
    return insertTextAt(range[0], text);
}
exports.insertTextBeforeRange = insertTextBeforeRange;
/**
 * Creates a fix command that replaces text at the node or token.
 * The fix is not applied until applyFixes() is called.
 * @param {Node|Token} nodeOrToken The node or token to remove.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 */
function replaceText(nodeOrToken, text) {
    return replaceTextRange(nodeOrToken.range, text);
}
exports.replaceText = replaceText;
/**
 * Creates a fix command that replaces text at the specified range in the source text.
 * The fix is not applied until applyFixes() is called.
 * @param {int[]} range The range to replace, first item is start of range, second
 *      is end of range.
 * @param {string} text The text to insert.
 * @returns {Operation} The fix command.
 */
function replaceTextRange(range, text) {
    return {
        range,
        text
    };
}
exports.replaceTextRange = replaceTextRange;
/**
 * Creates a fix command that removes the node or token from the source.
 * The fix is not applied until applyFixes() is called.
 * @param {Node|Token} nodeOrToken The node or token to remove.
 * @returns {Operation} The fix command.
 */
function remove(nodeOrToken) {
    return removeRange(nodeOrToken.range);
}
exports.remove = remove;
/**
 * Creates a fix command that removes the specified range of text from the source.
 * The fix is not applied until applyFixes() is called.
 * @param {int[]} range The range to remove, first item is start of range, second
 *      is end of range.
 * @returns {Operation} The fix command.
 */
function removeRange(range) {
    return {
        range,
        text: ''
    };
}
exports.removeRange = removeRange;
/**
 * Get text of Node
 * @param {Node} node The node to get text
 * @param {string} source The full text of the source code
 * @returns {Operation} The text of the node
 */
function getText(node, source) {
    const start = node === null || node === void 0 ? void 0 : node.range[0];
    const end = node === null || node === void 0 ? void 0 : node.range[1];
    return source.slice(start, end);
}
exports.getText = getText;
